@@ -1,6 +1,6 @@
 #!/bin/sh
 
-# $Id: tests.sh,v 1.71 2008/03/19 02:13:55 gilles Exp $  
+# $Id: tests.sh,v 1.79 2008/08/27 15:18:12 gilles Exp gilles $  
 
 #### Shell pragmas
 
@@ -130,6 +130,35 @@ locallocal() {
         fi
 }
 
+ll_timeout() {
+        if test X`hostname` = X"plume"; then
+                echo3 Here is plume
+                $CMD_PERL ./imapsync \
+                --host1 localhost  --user1 tata@est.belle \
+                --passfile1 /var/tmp/secret.tata \
+                --host2 localhost --user2 titi@est.belle \
+                --passfile2 /var/tmp/secret.titi \
+                --folder INBOX --timeout 1
+        else
+                :
+        fi
+}
+
+ll_timeout_ssl() {
+        if test X`hostname` = X"plume"; then
+                echo3 Here is plume
+                $CMD_PERL ./imapsync \
+                --host1 localhost  --user1 tata@est.belle \
+                --passfile1 /var/tmp/secret.tata \
+                --host2 localhost --user2 titi@est.belle \
+                --passfile2 /var/tmp/secret.titi \
+                --folder INBOX --timeout 5 --ssl1 --ssl2
+        else
+                :
+        fi
+}
+
+
 
 
 ll_folder() {
@@ -146,6 +175,22 @@ ll_folder() {
         fi
 }
 
+ll_oneemail() {
+        if test X`hostname` = X"plume"; then
+                echo3 Here is plume
+                $CMD_PERL ./imapsync \
+                --host1 localhost  --user1 tata@est.belle \
+                --passfile1 /var/tmp/secret.tata \
+                --host2 localhost --user2 titi@est.belle \
+                --passfile2 /var/tmp/secret.titi \
+                --folder INBOX.oneemail
+        else
+                :
+        fi
+}
+
+
+
 ll_folderrec() {
         if test X`hostname` = X"plume"; then
                 echo3 Here is plume
@@ -228,6 +273,22 @@ ll_internaldate() {
 }
 
 
+ll_idatefromheader() {
+        if test X`hostname` = X"plume"; then
+                echo3 Here is plume
+                sendtestmessage
+                $CMD_PERL ./imapsync \
+                --host1 localhost  --user1 tata@est.belle \
+                --passfile1 /var/tmp/secret.tata \
+                --host2 localhost --user2 titi@est.belle \
+                --passfile2 /var/tmp/secret.titi \
+                --folder INBOX.oneemail  \
+                --idatefromheader  --debug --dry
+        else
+                :
+        fi
+}
+
 
 
 ll_folder_rev() {
@@ -541,6 +602,7 @@ ll_regexmess()
 {
         if test X`hostname` = X"plume"; then
                 echo3 Here is plume
+                rm -f /home/vmail/titi/.yop.yap/cur/*
                 $CMD_PERL ./imapsync \
                 --host1 localhost --user1 tata@est.belle \
                 --passfile1 /var/tmp/secret.tata \
@@ -549,8 +611,10 @@ ll_regexmess()
                 --folder INBOX.yop.yap \
                 --regexmess 's/\157/O/g' \
                 --regexmess 's/p/Z/g' \
-                --dry --debug
-                echo 'rm /home/vmail/titi/.yop.yap/cur/*'
+                 --debug
+                file=`ls -t /home/vmail/titi/.yop.yap/cur/* | tail -1`
+                diff /var/tmp/imapsync/tests/ll_regexmess/dest_01 $file
+                #echo 'rm -f /home/vmail/titi/.yop.yap/cur/*'
         else
                 :
         fi
@@ -613,6 +677,20 @@ ll_regex_flag()
 }
 
 
+ssl_justconnect() {
+        if test X`hostname` = X"plume"; then
+                echo3 Here is plume
+                $CMD_PERL ./imapsync \
+		--host1 localhost \
+                --host2 localhost \
+                --ssl1 --ssl2 \
+                --justconnect
+        else
+                :
+        fi
+	
+}
+
 ll_ssl() {
         if test X`hostname` = X"plume"; then
                 echo3 Here is plume
@@ -721,6 +799,8 @@ ll_bigmail() {
 }
 
 
+
+
 msw() {
         sendtestmessage toto@est.belle
         scp imapsync  Admin@192.168.68.77:'C:/msys/1.0/home/Admin/imapsync/imapsync'
@@ -728,6 +808,31 @@ msw() {
 }
 
 
+
+
+gmail() {
+        if test X`hostname` = X"plume"; then
+                echo3 Here is plume
+                $CMD_PERL ./imapsync \
+                --host1 imap.gmail.com \
+                --ssl1 \
+                --user1 gilles.lamiral@gmail.com \
+                --passfile1 /var/tmp/secret.gilles_gmail \
+                --host2 localhost \
+                --ssl2 \
+                --user2 tata@est.belle \
+                --passfile2 /var/tmp/secret.tata \
+                --useheader 'Message-Id'  --skipsize \
+                --regextrans2 's/\[Gmail\]/Gmail/' \
+		#--dry # --debug --debugimap # --authmech1 LOGIN
+                
+        else
+                :
+        fi
+
+}
+
+
 ##########################
 # specific tests
 ##########################
@@ -937,6 +1042,17 @@ ariasolutions2() {
         # --dry --debug --debugimap
 
 
+}
+
+genomics() {
+
+# Blocked, timeout ignored
+./imapsync \
+ --host1 mail.genomics.org.cn --user1 lamiral --passfile1 /var/tmp/secret.genomics \
+ --host2 szmail.genomics.cn   --user2 lamiral --passfile2 /var/tmp/secret.genomics \
+ --sep1 . --prefix1 'INBOX.' --folder INBOX  --useheader 'Message-Id' --expunge --skipsize \
+ --timeout 7  --debug --debugimap
+
 }
 ##########################
 ##########################
@@ -959,11 +1075,13 @@ test $# -eq 0 && run_tests \
         option_tests \
         first_sync \
         locallocal \
+        ll_timeout \
         ll_folder \
         ll_buffersize \
         ll_justfolders \
         ll_prefix12 \
         ll_internaldate \
+        ll_idatefromheader \
         ll_folder_rev \
         ll_subscribed \
         ll_subscribe \
@@ -996,7 +1114,9 @@ test $# -eq 0 && run_tests \
         ll_delete2 \
         ll_folderrec \
         ll_bigmail \
-        msw
+        gmail \
+        ssl_justconnect \
+#        msw
 
 
 
